precision mediump float;
varying vec2 vTextureCoord;
uniform sampler2D uTexture;

uniform float uStripeNum;


const float PI=3.14;




vec3 RGB2HSV(vec3 rgb){

        float R=rgb.x;
        float G=rgb.y;
        float B=rgb.z;

        float h;
        float s;
        float v;
        float max1=max(R,max(G,B));
        float min1=min(R,min(G,B));

        if(max1 != 0.0){
            s=(max1-min1)/max1;
        }else{
            s=0.0;
        }
        if(R==max1){
            h=(G-B)/(max1-min1);
        } else if(G==max1){
            h=2.0+(B-R)/(max1-min1);
        } else if(B==max1){
            h=4.0+(R-G)/(max1-min1);
        }
        h=h*60.0;
        if(h<0.0){
            h=h+360.0;
        }
        v=max1;
        return vec3(h,s,v);

}

vec3 HSV2RGB(vec3 hsv){

        float R;
        float G;
        float B;
        if(hsv.y==0.0){
            R=G=B=hsv.z;
        }else{
            hsv.x=hsv.x/60.0;
//            int i=int(hsv.x-6.0*floor(hsv.x/6.0));
            int i=int(floor(hsv.x));
            float f=hsv.x-float(i);
            float a=hsv.z*(1.0-hsv.y);
            float b=hsv.z*(1.0-hsv.y*f);
            float c=hsv.z*(1.0-hsv.y*(1.0-f));


            if(i==0){
                R=hsv.z;
                G=c;
                B=a;
            }else if(i==1){
                R=b;
                G=hsv.z;
                B=a;
            }else if(i==2){
                R=a;
                G=hsv.z;
                B=c;
            }else if(i==3){
                R=a;
                G=b;
                B=hsv.z;
            }else if(i==4){
                R=c;
                G=a;
                B=hsv.z;
            }else if(i==5){
                R=hsv.z;
                G=a;
                B=b;
            }
        }

        return vec3(R,G,B);
}


void main(){

    float factor=sin(vTextureCoord.y*PI*uStripeNum);
    float factor2=(factor+1.0)/2.0;
    vec4 color=texture2D(uTexture,vTextureCoord);


   vec3 hsvColor=RGB2HSV(color.rgb);
   float temp=hsvColor.x*factor2;

   vec3 changehsv=vec3(temp,hsvColor.y,hsvColor.z);
   gl_FragColor=vec4(HSV2RGB(changehsv),color.a);

}